==> haskell-incremental-parser-0.2.5-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-incremental-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: incremental-parser
version: 0.2.5
id: incremental-parser-0.2.5-4m29DibcxbxAhlcLYlnkjf
key: incremental-parser-0.2.5-4m29DibcxbxAhlcLYlnkjf
license: GPL
copyright: (c) 2011-2016 Mario Blazevic
maintainer: blamario@yahoo.com
homepage: https://github.com/blamario/incremental-parser
synopsis: Generic parser library capable of providing partial results from partial input.
description:
    This package defines yet another parser combinator library. This one is implemented using the concept of Brzozowski
    derivatives, tweaked and optimized to work with any monoidal input type. Lists, ByteString, and Text are supported out
    of the box, as well as any other data type for which the monoid-subclasses package defines instances. If the parser
    result is also a monoid, its chunks can be extracted incrementally, before the complete input is parsed.
category: Parsing
author: Mario Blazevic
exposed: True
exposed-modules:
    Text.ParserCombinators.Incremental
    Text.ParserCombinators.Incremental.LeftBiasedLocal
    Text.ParserCombinators.Incremental.Symmetric
    Control.Applicative.Monoid
abi: 21fd66e2cdea9d1e712875ab1fe3290d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/incremental-parser-0.2.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/incremental-parser-0.2.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/incremental-parser-0.2.5
hs-libraries: HSincremental-parser-0.2.5-4m29DibcxbxAhlcLYlnkjf
depends:
    base-4.9.0.0 monoid-subclasses-0.4.3.1-KxZSRwmf8rR353MuGWEfhz
haddock-interfaces: /usr/share/doc/haskell-incremental-parser/html/incremental-parser.haddock
haddock-html: /usr/share/doc/haskell-incremental-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-incremental-parser-0.2.5-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-incremental-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: incremental-parser
version: 0.2.5
id: incremental-parser-0.2.5-CO2FBdfxmPB4PXTif5VHr8
key: incremental-parser-0.2.5-CO2FBdfxmPB4PXTif5VHr8
license: GPL
copyright: (c) 2011-2016 Mario Blazevic
maintainer: blamario@yahoo.com
homepage: https://github.com/blamario/incremental-parser
synopsis: Generic parser library capable of providing partial results from partial input.
description:
    This package defines yet another parser combinator library. This one is implemented using the concept of Brzozowski
    derivatives, tweaked and optimized to work with any monoidal input type. Lists, ByteString, and Text are supported out
    of the box, as well as any other data type for which the monoid-subclasses package defines instances. If the parser
    result is also a monoid, its chunks can be extracted incrementally, before the complete input is parsed.
category: Parsing
author: Mario Blazevic
exposed: True
exposed-modules:
    Text.ParserCombinators.Incremental
    Text.ParserCombinators.Incremental.LeftBiasedLocal
    Text.ParserCombinators.Incremental.Symmetric
    Control.Applicative.Monoid
abi: 246d7150ff5e106737b1d05ac3f16270
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/incremental-parser-0.2.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/incremental-parser-0.2.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/incremental-parser-0.2.5
hs-libraries: HSincremental-parser-0.2.5-CO2FBdfxmPB4PXTif5VHr8
depends:
    base-4.9.0.0 monoid-subclasses-0.4.3.1-GRQqX1kHYMV791dQTJH418
haddock-interfaces: /usr/share/doc/haskell-incremental-parser/html/incremental-parser.haddock
haddock-html: /usr/share/doc/haskell-incremental-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
